pyxmpp.sasl.core.ClientAuthenticator

Package pyxmpp :: Package sasl :: Module core :: Class ClientAuthenticator |
[hide private]

# Class ClientAuthenticator

source code

Known Subclasses:
  - plain.PlainClientAuthenticator
  - , digest_md5.DigestMD5ClientAuthenticator

Base class for client authenticators.

A client authenticator class is a client-side implementation of a SASL mechanism. One ClientAuthenticator object may be used for one client authentication process.

Instance Methods | [hide private]
__init__(self, password_manager) Initialize a ClientAuthenticator object. | source code
Response or Failure |
start(self, username, authzid) Start the authentication process. | source code
Response or Failure |
challenge(self, challenge) Process the server's challenge. | source code
Success or Failure |
finish(self, data) Handle authentication succes information from the server. | source code

Method Details | [hide private]

### __init__(self, password_manager) (Constructor) | source code
Initialize a ClientAuthenticator object. Parameters: `password_manager` (PasswordManager) - a password manager providing authentication credentials.

### start(self, username, authzid) | source code
Start the authentication process. Parameters: `username` (`unicode`) - the username (authentication id). `authzid` (`unicode`) - the authorization id requester. Returns: Response or Failure the initial response to send to the server or a failuer indicator.

### challenge(self, challenge) | source code
Process the server's challenge. Parameters: `challenge` (`str`) - the challenge. Returns: Response or Failure the response or a failure indicator.

### finish(self, data) | source code
Handle authentication succes information from the server. Parameters: `data` (`str`) - the optional additional data returned with the success. Returns: Success or Failure success or failure indicator.